#!/bin/bash

TARGDIR=/opt/ark_backups
TEMPDIR=/tmp/ark_backups
SOURCEDIR=/home/steam/ark/ShooterGame/Saved
ODATE=`date +%Y-%m-%d`
ODATE_LONG=`date +%Y-%m-%d_%H_%M`

mkdir -p $TARGDIR
mkdir -p $TEMPDIR

FILELIST=$TARGDIR/filelist.txt

# save all worlds before backing up
#echo -n "Saving worlds, this may take some time..."
#arkmanager saveworld @all

#for (( i=1; i<30; i++ )); do
#	sleep 1
#	echo -n "."
#done
#echo "done"

while read -r line; do 
	if [[ $line = "" ]]; then
		continue
	fi

	filearr=( $line )
	arr_dir=${filearr[0]}
	filearr=("${filearr[@]:1}")

	# ignore commented out lines
	if [[ $arr_dir == "#" ]]; then
		continue
	fi

	# configure directories
	t_dir=$TEMPDIR/$arr_dir
	o_dir=$TARGDIR/$ODATE/$arr_dir
	s_dir=$SOURCEDIR/$arr_dir

	# sanity check
	if [ -d $s_dir ]; then
		echo -n "Backing up $arr_dir..."
	else
		echo "Invalid entry $arr_dir, skipping"
		continue
	fi

	mkdir -p $t_dir
	mkdir -p $o_dir
	rm -rf $t_dir/*

	# copy all files for backup
	for f in $filearr; do
		cp $s_dir/$f $t_dir
	done
	cp $s_dir/*AntiCorruptionBackup.bak $t_dir 2> /dev/null
	cp $s_dir/*.arktribe $t_dir 2> /dev/null
	cp $s_dir/*.tribebak $t_dir 2> /dev/null
	cp $s_dir/*.arkprofile $t_dir 2> /dev/null
	cp $s_dir/*.arktributetribe $t_dir 2> /dev/null
	if [ -d $s_dir/ServerPaintingCache ]; then
		cp -r $s_dir/ServerPaintingCache $t_dir 2> /dev/null
	fi

	# compres backup
	tar -cJf $o_dir/${arr_dir}_${ODATE_LONG}.tar.xz $t_dir/* 2> /dev/null

	echo "done"

	# delete temporary files
	rm -rf $t_dir/*

done < $FILELIST

echo "Backing up configuration files...done"
mkdir -p $TARGDIR/configs/$ODATE/arkmanager/instances
mkdir -p $TARGDIR/configs/$ODATE/ini

echo "Backing up transfer directory...done"
mkdir -p $TARGDIR/cluster/$ODATE
tar -cJf $TARGDIR/cluster/$ODATE/clusterbak_${ODATE_LONG}.tar.xz /home/steam/ark/cluster/clusterdata/clusters/astncluster/* 2> /dev/null

cp /etc/arkmanager/arkmanager.cfg $TARGDIR/configs/$ODATE/arkmanager/
cp /etc/arkmanager/instances/*cfg $TARGDIR/configs/$ODATE/arkmanager/instances/
cp /home/steam/ark/ShooterGame/Saved/Config/LinuxServer/Game*ini $TARGDIR/configs/$ODATE/ini

chown -R steam $TARGDIR
chown -R steam $TEMPDIR
